@@ -1,8 +1,11 @@
 (defvar rail-install-list
   '("rail-user-agent.el"
     "rail-table-mule.el"
+    "rail-table-meadow.el"
+    "rail-table-xemacs.el"
     "rail-table-flim.el"
     "rail-table-semi.el"
+    "rail-pj.el"
     "rail.el"))
 
 (or (fboundp 'make-directory-internal)
